// Load the hospital data
d3.csv(
  'https://gist.githubusercontent.com/kusuma63663/d1f8cf7d4008654620b8f2f61df56a9f/raw/9ae27554deb5388dfd47adfd175a09965c20209e/Hospital%2520csv',
).then(function (data) {
  // Convert data to hierarchical structure
  const departments = d3.group(
    data,
    (d) => d.department_referral,
  );
  const root = d3.hierarchy({
    name: 'Root',
    children: Array.from(departments, ([key, value]) => ({
      name: key,
      children: value,
    })),
  });

  // Set up dimensions and margins
  const width = 600;
  const height = 400;
  const margin = {
    top: 20,
    right: 50,
    bottom: 20,
    left: 50,
  };

  // Create a tree layout
  const treeLayout = d3.tree().size([height, width]);

  // Append an SVG element to the body
  const svg = d3
    .select('#tree-container')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, ${margin.top})`,
    );

  // Assigns the x and y position for the nodes
  const treeData = treeLayout(root);

  // Add links between nodes
  svg
    .selectAll('.link')
    .data(treeData.links())
    .enter()
    .append('path')
    .attr('class', 'link')
    .attr(
      'd',
      d3
        .linkHorizontal()
        .x((d) => d.y)
        .y((d) => d.x),
    );

  // Add nodes
  const nodes = svg
    .selectAll('.node')
    .data(treeData.descendants())
    .enter()
    .append('g')
    .attr('class', 'node')
    .attr('transform', (d) => `translate(${d.y},${d.x})`);

  // Add circles to represent nodes
  nodes.append('circle').attr('r', 5);

  // Add text labels
  nodes
    .append('text')
    .attr('dy', '0.31em')
    .attr('x', (d) => (d.children ? -13 : 13))
    .attr('text-anchor', (d) =>
      d.children ? 'end' : 'start',
    )
    .text((d) => d.data.name);
});
